"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MerkleDistributorSDK = void 0;
const anchor_contrib_1 = require("@saberhq/anchor-contrib");
const solana_contrib_1 = require("@saberhq/solana-contrib");
const constants_1 = require("./constants");
const merkle_distributor_1 = require("./idls/merkle_distributor");
const wrapper_1 = require("./wrapper");
class MerkleDistributorSDK {
    constructor(provider, program) {
        this.provider = provider;
        this.program = program;
    }
    withSigner(signer) {
        return MerkleDistributorSDK.load({
            provider: this.provider.withSigner(signer),
        });
    }
    /**
     * Loads the SDK.
     * @returns {MerkleDistributorSDK}
     */
    static load({ provider, }) {
        const aug = new solana_contrib_1.SolanaAugmentedProvider(provider);
        return new MerkleDistributorSDK(aug, (0, anchor_contrib_1.newProgram)(merkle_distributor_1.MerkleDistributorJSON, constants_1.PROGRAM_ID, aug));
    }
    /**
     * Load an existing merkle distributor.
     * @returns {MerkleDistributorWrapper}
     */
    async loadDistributor(key) {
        return await wrapper_1.MerkleDistributorWrapper.load(this, key);
    }
    /**
     * Create a merkle distributor.
     * @returns {PendingDistributor}
     */
    async createDistributor(args) {
        return await wrapper_1.MerkleDistributorWrapper.createDistributor({
            sdk: this,
            ...args,
        });
    }
}
exports.MerkleDistributorSDK = MerkleDistributorSDK;
//# sourceMappingURL=sdk.js.map