import { u64 } from "@saberhq/token-utils";
import { PublicKey } from "@solana/web3.js";
import BN from "bn.js";
import invariant from "tiny-invariant";
import { BalanceTree } from "./balance-tree";
export function parseBalanceMap(balances) {
    const dataByAddress = balances.reduce((memo, { address: account, earnings }) => {
        if (memo[account.toString()]) {
            throw new Error(`Duplicate address: ${account.toString()}`);
        }
        const parsedNum = new u64(earnings);
        if (parsedNum.lte(new u64(0))) {
            throw new Error(`Invalid amount for account: ${account.toString()}`);
        }
        memo[account.toString()] = {
            amount: parsedNum,
        };
        return memo;
    }, {});
    const sortedAddresses = Object.keys(dataByAddress).sort();
    // construct a tree
    const tree = new BalanceTree(sortedAddresses.map((address) => {
        const addressData = dataByAddress[address];
        invariant(addressData, "addressData");
        return {
            account: new PublicKey(address),
            amount: addressData.amount,
        };
    }));
    // generate claims
    const claims = sortedAddresses.reduce((memo, address, index) => {
        const addressData = dataByAddress[address];
        invariant(addressData, "addressData");
        const { amount, flags } = addressData;
        memo[address] = {
            index,
            amount: amount,
            proof: tree.getProof(index, new PublicKey(address), amount),
            ...(flags ? { flags } : {}),
        };
        return memo;
    }, {});
    const tokenTotal = sortedAddresses.reduce((memo, key) => { var _a, _b; return memo.add((_b = (_a = dataByAddress[key]) === null || _a === void 0 ? void 0 : _a.amount) !== null && _b !== void 0 ? _b : new BN(0)); }, new BN(0));
    return {
        merkleRoot: tree.getRoot(),
        tokenTotal: tokenTotal.toString(),
        claims,
    };
}
//# sourceMappingURL=parse-balance-map.js.map